Model extensions
================

:synopsis: Current Model Extensions


Current Database Model Extensions
---------------------------------

* *TimeStampedModel* - TimeStampedModel An abstract base class model that
  provides self-managed "created" and "modified" fields.
* *TitleDescriptionModel* - An abstract base class model that provides
  "title" and "description" fields.
* *TitleSlugDescriptionModel* - An abstract base class model that provides
  "title" and "description" fields and a self-managed "slug" field
  that populates from the title.
